| Safe Haskell | Safe |
|---|---|
| Language | Haskell98 |
UHC.Util.Hashable
Description
Re-export of hashable package, in addition providing some of the instances for datatypes defined in the remainder of the uhc-util package.
Documentation
module Data.Hashable
uhc-util-0.1.6.6: UHC utilities
| Safe Haskell | Safe |
|---|---|
| Language | Haskell98 |
UHC.Util.Hashable
Description
Re-export of hashable package, in addition providing some of the instances for datatypes defined in the remainder of the uhc-util package.
module Data.Hashable