| Safe Haskell | Safe |
|---|---|
| Language | Haskell98 |
UHC.Util.RLList.LexScope
Contents
Description
LexScope represents a lexical scoping, encoded as a list of Int.
uhc-util-0.1.6.6: UHC utilities
| Safe Haskell | Safe |
|---|---|
| Language | Haskell98 |
UHC.Util.RLList.LexScope
Contents
Description
LexScope represents a lexical scoping, encoded as a list of Int.